@@ -24,7 +24,7 @@ NULL
 #' estimated via confidence interval. 
 #'@slot beta0 Vector of null hypothesis values for the linear parameters of the model. Used only if \code{test} is not 0 and \code{component} is not 2.
 #'@slot f0 Function representing the expression of the nonparametric component f under the null hypothesis. Used only if \code{component} is not 1.
-#'@slot f0_eval Vector of f0 evaluations at the choosen test locations. It will be eventually set later in checkInferenceParameters, if nonparametric inference is required. 
+#'@slot f0_eval Vector of f0 evaluations at the chosen test locations. It will be eventually set later in checkInferenceParameters, if nonparametric inference is required. 
 #'@slot f_var An integer taking value 1 or 2. If 1 local variance estimates for the nonlinear part of the model will be computed,
 #'whereas if 2 they will not.
 #'@slot quantile Vector of quantiles needed for confidence intervals, used only if interval is not 0.
@@ -69,21 +69,21 @@ inferenceDataObject<-setClass("inferenceDataObject", slots = list(test = "intege
 #'
 #'@param test A string defining the type of test to be performed. Multiple tests can be required. In this case the length of the list needs to be coherent with the ones of \code{type},
 #' \code{component} and \code{interval}. The default is NULL, and can take values:
-#'\itemize{
+#'\describe{
 #'\item{'oat'}{: one-at-the-time tests, available only when \code{component} is 'parametric'.}
 #'\item{'sim'}{: simultaneous tests.}
 #'\item{'none'}{: no test required. \code{interval} must be set.}
 #'}
 #'@param interval A string defining the type of confidence intervals to be computed. Multiple intervals can be required. In this case the length of the list needs to be coherent with the ones of \code{type},
 #'\code{component} and \code{test}. The default is NULL, and can take values:
-#'\itemize{
+#'\describe{
 #'\item{'oat'}{: one-at-the-time intervals.}
 #'\item{'sim'}{: simultaneous intervals, available only when \code{component} is 'parametric' and no sign-flipping approaches are required.}
 #'\item{'bonf'}{: Bonferroni intervals, available only when \code{component} is 'parametric'}
 #'\item{'none'}{: no interval required. \code{test} must be set.}
 #'}
 #'@param type A list of strings defining the type of implementation for the inferential analysis. The possible values are:
-#'\itemize{
+#'\describe{
 #'\item{'w'}{: Wald parametric approach (default).}
 #'\item{'s'}{: Speckman parametric approach.}
 #'\item{'sf'}{: sign-flip nonparametric approach.}
@@ -96,7 +96,7 @@ inferenceDataObject<-setClass("inferenceDataObject", slots = list(test = "intege
 #'@param locations A matrix of the locations of interest when testing the nonparametric component f, defaulted to NULL
 #'@param locations_indices A vector of indices indicating the locations to be considered among the observed ones for nonparametric inference, defaulted to NULL.
 #'If a vector of indices is provided, then the slot 'locations' is discarded.
-#'@param locations_by_nodes A logical used to indicate wether the selected locations to perform inference on f are all coinciding with the nodes;  
+#'@param locations_by_nodes A logical used to indicate whether the selected locations to perform inference on f are all coinciding with the nodes;  
 #'@param coeff A matrix, with \code{n_cov} number of columns, of numeric coefficients representing the linear combinations of the parametric components of the model.
 #'The default is NULL, corresponding to an identity matrix. If at least one sing-flipping approach is required in \code{type}, needs to be an identity matrix.
 #'@param beta0 Vector of real numbers (default NULL). It is used only if the \code{test} parameter is set, and \code{component} is not 'nonparametric'; its length is the number of rows of matrix \code{coeff} if provided. 
@@ -163,11 +163,11 @@ inferenceDataObjectBuilder<-function(test = NULL,
   }
   
   if(length(type)==0)
-    stop("'type' is zero dimensional, should be a vector taking values among 'w', 's', 'sf' or 'esf'")
+    stop("'type' is zero dimensional, should be a vector taking values among 'w', 's', 'sf', 'esf' or 'enh-esf")
  
    if(length(type) > 1 || type!="w"){
     if(!is(type,"character"))
-      stop("'type' should be a vector of characters: choose among 'w', 's', 'sf' or 'esf'" )
+      stop("'type' should be a vector of characters: choose among 'w', 's', 'sf', 'esf' or 'enh-esf'" )
   }
   
   
@@ -423,7 +423,7 @@ inferenceDataObjectBuilder<-function(test = NULL,
   for (index in 1:n_of_implementations){
     
       if(type[index]!="w" & type[index]!="s" & type[index]!="esf" & type[index]!="enh-esf" & type[index]!="sf"){
-        stop("type should be chosen between 'w', 's' 'sf', 'esf' or 'enh-esf'")}else{
+        stop("type should be chosen between 'w', 's', 'sf', 'esf' or 'enh-esf'")}else{
           if(type[index]=="w") type_numeric[index]=as.integer(1)
           if(type[index]=="s") type_numeric[index]=as.integer(2)
           if(type[index]=="esf") type_numeric[index]=as.integer(3)
